@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>", 
@@ -43,31 +43,31 @@ dscore <- compute_iat(iat_data, Dscore = "d3")
 str(dscore)
 
 ## -----------------------------------------------------------------------------
-descript_d(dscore) # Data frame containing IAT D-scores
+descript_d(dscore) # Data frame containing IAT Ds
 
 ## -----------------------------------------------------------------------------
-descript_d(dscore, # Data frame containing IAT D-scores
+descript_d(dscore, # Data frame containing IAT Ds
            latex = TRUE) # obtain the code for latex tables
 
 ## -----------------------------------------------------------------------------
 IAT_rel(dscore)
 
-## ---- fig.align='center', fig.width=6, fig.cap="d_point() function with default settings"----
-d_point(dscore) # Data frame containing IAT D-scores
+## ----fig.align='center', fig.width=6, fig.cap="d_point() function with default settings"----
+d_point(dscore) # Data frame containing IAT D scores
 
-## ---- fig.align='center', fig.width=6, fig.cap="d_point() function with   settings change"----
-d_point(dscore, # dataframe containing IAT D-scores
+## ----fig.align='center', fig.width=6, fig.cap="d_point() function with   settings change"----
+d_point(dscore, # dataframe containing IAT Ds
        order_sbj = "D-decreasing", # change respondents order
-       x_values = FALSE, # remove respodents' labels
+       x_values = FALSE, # remove respondents' labels
        include_stats = TRUE, # include descriptive statistics
        col_point = "lightskyblue") # change points color
 
-## ---- fig.align='center', fig.width=6, fig.cap="d_density() function with default settings"----
+## ----fig.align='center', fig.width=6, fig.cap="d_density() function with default settings"----
 d_density(dscore) # dataframe containing IAT Dscores
 
 ## ----sampleSettings, fig.align='center', fig.width=6, fig.cap="\\label{fig:sampleSettings}d_density() function with settings change"----
 d_density(dscore, # dataframe containing IAT Dscores
-        graph = "violin", # change graphical representation
+        graph = "boxplot", # change graphical representation
         include_stats = TRUE) # include descriptive statistics
 
 ## -----------------------------------------------------------------------------
@@ -80,6 +80,6 @@ multi_d <- multi_scores[[1]]
 head(multi_d)
 str(multi_d)
 
-## ---- fig.align='center', fig.width=6, fig.cap="Multiple D-scores representation"----
+## ----fig.align='center', fig.width=6, fig.cap="Multiple IAT D scores representation"----
 multi_scores[[2]]
 
